Signed-off-by: Florian Westphal <f...@strlen.de>
---
 net/can/gw.c | 14 ++++++++++----
 1 file changed, 10 insertions(+), 4 deletions(-)

diff --git a/net/can/gw.c b/net/can/gw.c
index 73a02af4b5d7..398dd0395ad9 100644
--- a/net/can/gw.c
+++ b/net/can/gw.c
@@ -1014,6 +1014,8 @@ static struct pernet_operations cangw_pernet_ops = {
 
 static __init int cgw_module_init(void)
 {
+       int ret;
+
        /* sanitize given module parameter */
        max_hops = clamp_t(unsigned int, max_hops, CGW_MIN_HOPS, CGW_MAX_HOPS);
 
@@ -1031,15 +1033,19 @@ static __init int cgw_module_init(void)
        notifier.notifier_call = cgw_notifier;
        register_netdevice_notifier(&notifier);
 
-       if (__rtnl_register(PF_CAN, RTM_GETROUTE, NULL, cgw_dump_jobs, 0)) {
+       ret = rtnl_register_module(THIS_MODULE, PF_CAN, RTM_GETROUTE,
+                                  NULL, cgw_dump_jobs, 0);
+       if (ret) {
                unregister_netdevice_notifier(&notifier);
                kmem_cache_destroy(cgw_cache);
                return -ENOBUFS;
        }
 
-       /* Only the first call to __rtnl_register can fail */
-       __rtnl_register(PF_CAN, RTM_NEWROUTE, cgw_create_job, NULL, 0);
-       __rtnl_register(PF_CAN, RTM_DELROUTE, cgw_remove_job, NULL, 0);
+       /* Only the first call to rtnl_register_module can fail */
+       rtnl_register_module(THIS_MODULE, PF_CAN, RTM_NEWROUTE,
+                            cgw_create_job, NULL, 0);
+       rtnl_register_module(THIS_MODULE, PF_CAN, RTM_DELROUTE,
+                            cgw_remove_job, NULL, 0);
 
        return 0;
 }
-- 
2.13.6

Reply via email to